package com.example.nto.controller;


import com.example.nto.dto.EmployeeDTO;
import com.example.nto.dto.RegisterDTO;
import com.example.nto.entity.Code;
import com.example.nto.entity.Employee;
import com.example.nto.service.impl.EmployeeServiceImpl;
import lombok.AllArgsConstructor;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.core.Authentication;
import org.springframework.web.bind.annotation.*;

import java.time.LocalDateTime;
import java.util.Optional;

@RestController
@RequestMapping("/api/employee")
@AllArgsConstructor
public class EmployeeController {
    private EmployeeServiceImpl service;

    @GetMapping("/{username}")
    public ResponseEntity<String> findEmployeeByUsername(@PathVariable String username){
        Employee volunteer = service.findEmployeeByUsername(username);
        return ResponseEntity.status(HttpStatus.OK).body("Employee with username "+username+" exists");
    }

    @GetMapping("/{login}/auth")
    private ResponseEntity<String> getAuth(@PathVariable("login") String login){

        if(login==null||login.trim().isEmpty()){
            return ResponseEntity.status(400).body("что-то пошло не так");
        }

        Employee employee = service.findEmployeeByUsername(login);
        if(employee!=null){
            return ResponseEntity.status(200).body("данный логин существует - можно пользоваться приложением");

        }
        else{
            return ResponseEntity.status(401).body("логина не существует или неверный");
        }



    }

    @GetMapping("/{login}/info")
    private ResponseEntity<Object> getInfo(@PathVariable("login") String login){
        if(login==null||login.trim().isEmpty()){
            return ResponseEntity.status(400).body("что-то пошло не так");
        }

        Employee employee = service.findEmployeeByUsername(login);
        if(employee!=null){
            return ResponseEntity.ok(employee);


        }
        else{
            return ResponseEntity.status(401).body("логина не существует или неверный");
        }

    }

    @PatchMapping("/{login}/open")
    private ResponseEntity<Object> updateLocalTime(@PathVariable("login") String login, @RequestBody  Code code){
        if(login==null||login.trim().isEmpty()){
            return ResponseEntity.status(400).body("что-то пошло не так");
        }
        if(code.getValue()==0||code==null){
            return ResponseEntity.status(400).body("что-то пошло не так");
        }

        Employee employee = service.findEmployeeByUsername(login);
        if(employee!=null){
            employee.setLastVisit(LocalDateTime.now().toString());
            service.updateLocalTime(employee);

            return ResponseEntity.status(200).body("дверь открылась");
        }
        else {
            return ResponseEntity.status(401).body("логина не существует или неверный");
        }
    }



    @PostMapping("/registration")
    public ResponseEntity<EmployeeDTO> registerEmployee(@RequestBody RegisterDTO dto) {
        return ResponseEntity.status(HttpStatus.OK).body(service.createEmployee(dto));
    }

    @GetMapping("/login")
    public ResponseEntity<EmployeeDTO> getLogin(Authentication authentication){
        return ResponseEntity.status(HttpStatus.OK).body(service.findEmployeeDTOByUsername(authentication.getName()));
    }

}
